aboutsummaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
authorAlessandro Salvatori <sandr8@gmail.com>2010-07-05 11:01:23 +0100
committerMichael Brown <mcb30@ipxe.org>2010-07-05 11:01:23 +0100
commit3cefc5a3e0126c65f24475a3eba19b7248fc02bf (patch)
treeb5fc3d9608b34d06c506a289431caaa2f40ac719
parentc84a2c81a75a0cf428995aca7e7bd4efafecd47b (diff)
downloadipxe-3cefc5a3e0126c65f24475a3eba19b7248fc02bf.tar.gz
[refcnt] Fix embedded image building
Modified-by: Michael Brown <mcb30@ipxe.org> Signed-off-by: Michael Brown <mcb30@ipxe.org>
-rw-r--r--src/include/ipxe/refcnt.h6
1 files changed, 3 insertions, 3 deletions
diff --git a/src/include/ipxe/refcnt.h b/src/include/ipxe/refcnt.h
index 37f574dcc..49fce5044 100644
--- a/src/include/ipxe/refcnt.h
+++ b/src/include/ipxe/refcnt.h
@@ -69,10 +69,10 @@ ref_init ( struct refcnt *refcnt,
/**
* Initialise a static reference counter
*
* @v free Free containing object
*/
-#define REF_INIT( free ) { \
- .free = free, \
+#define REF_INIT( free_fn ) { \
+ .free = free_fn, \
}
extern struct refcnt * ref_get ( struct refcnt *refcnt );
@@ -69,10 +69,10 @@ ref_init ( struct refcnt *refcnt,
* Initialise a static reference counter
*
- * @v free Free containing object
+ * @v free_fn Free containing object
*/